package com.mudu.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mudu.base.controller.BaseController;
import com.mudu.base.domain.AjaxResult;
import com.mudu.entity.ASafeQyjcxx;
import com.mudu.service.ASafeQyjcxxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * (ASafeQyjcxx)表控制层
 *
 * @author wu
 * @since 2024-02-26 10:43:24
 */
@RestController
@RequestMapping("pharmaceuticals/aSafeQyjcxx")
@Api(tags = "企业信息")
@Transactional(rollbackFor = Exception.class)
public class ASafeQyjcxxController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private ASafeQyjcxxService aSafeQyjcxxService;

    /**
     * 分页条件查询所有数据
     *
     * @param page        分页条件
     * @param aSafeQyjcxx 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询", response = ASafeQyjcxx.class)
    public AjaxResult page(Page<ASafeQyjcxx> page, ASafeQyjcxx aSafeQyjcxx) {
        return success(aSafeQyjcxxService.page(page, new QueryWrapper<>(aSafeQyjcxx)));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条", response = ASafeQyjcxx.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(aSafeQyjcxxService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param aSafeQyjcxx 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增", response = ASafeQyjcxx.class)
    public AjaxResult insert(@RequestBody ASafeQyjcxx aSafeQyjcxx) {
        return success(aSafeQyjcxxService.save(aSafeQyjcxx));
    }

    /**
     * 修改数据
     *
     * @param aSafeQyjcxx 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改")
    public AjaxResult update(@RequestBody ASafeQyjcxx aSafeQyjcxx) {
        return success(aSafeQyjcxxService.updateById(aSafeQyjcxx));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(aSafeQyjcxxService.removeByIds(idList));
    }

    /**
     * 数据同步
     *
     * @return 响应类
     */
    @GetMapping("/dataSynchronous")
    @ApiOperation(value = "数据同步")
    public AjaxResult dataSynchronous() {
        aSafeQyjcxxService.dataSynchronous();
        return success();
    }


    /**
     * 获取企业xxbh
     *
     * @return 响应类
     */
    @GetMapping("/getQyXxbh")
    @ApiOperation(value = "获取企业xxbh")
    public AjaxResult getQyXxbh(@RequestParam("qymc") String qymc, @RequestParam("xybm") String xybm) {
        return success(aSafeQyjcxxService.findOneByqymcOrXybm(qymc,xybm));
    }
}

