package com.mudu.quartz;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.mudu.entity.*;
import com.mudu.entity.dto.request.ACheckQuatzRequest;
import com.mudu.entity.dto.request.ACheckQuatzZichaRequest;
import com.mudu.entity.dto.response.ACheckXcTpResponse;
import com.mudu.entity.dto.response.RwzqUuidResponse;
import com.mudu.service.*;
import com.mudu.service.impl.LoginService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * @author dong
 * @since 2024/3/12 16:37
 */
//@RestController
//@RequestMapping("pharmaceuticals/aCheck")
//@Api(tags = "新增")
@Transactional(rollbackFor = Exception.class)
@Configuration
@EnableScheduling
public class AcheckTaskQuartz {
    Logger logger = LoggerFactory.getLogger(AcheckTaskQuartz.class);
    /**
     * 服务对象
     */
    @Resource
    private ASafeXcrwService aSafeXcrwService;

    /**
     * 服务对象
     */
    @Resource
    private ASafeXcrwjcxService aSafeXcrwjcxService;

    @Resource
    private ASafeXcrwjcxzgxxService aSafeXcrwjcxzgxxService;

    @Resource
    private ASafeYhzgxxService aSafeYhzgxxService;


    @Resource
    private ASafeZcrwService aSafeZcrwService;


    @Resource
    private ASafeZcrwjlService aSafeZcrwjlService;


    @Resource
    private ASafeRwfjService aSafeRwfjService;


    @Resource
    private ASafeZcrwwzService aSafeZcrwwzService;


    @Resource
    private SzsASafeZcyhxxService szsASafeZcyhxxService;


    @Resource
    private ASafeXcrwwzService aSafeXcrwwzService;


    @Resource
    private ASafeQyjcxxService aSafeQyjcxxService;

    @Resource
    private ASafeTfgService aSafeTfgService;


    @Resource
    private ASafeTfgshService aSafeTfgshService;

    @Resource
    private ASafeRwzqService aSafeRwzqService;

    @Resource
    private LoginService loginService;

    @Value("${improveUrl}")
    private String url;

    @Value("${api}")
    private String api;

    @Value("${zcUrl}")
    private String zcUrl;

    @Value("${imUrl}")
    private String imUrl;

    @Value("${zcXxUrl}")
    private String zcXxUrl;

    @Value("${zczqUrl}")
    private String zczqUrl;

    @Value("${xczqUrl}")
    private String xczqUrl;

    @Value("${tfgUrl}")
    private String tfgUrl;

    /**
     * 木渎二期token
     */
    private String token;

    private void getToken() {
        token = "Bearer " + loginService.getToken();
    }


    /**
     * 新增创建时间为昨天且处于审批通过的工单数据
     *
     * @Param qymc 企业名称
     */
    @Scheduled(cron = "0 0 4 * * ? ")
//    @Scheduled(cron = "0 0/5 * * * ?")
//    @PostMapping("/insert")
//    @ApiOperation(value = "新增创建时间为昨天且处于审批通过的工单数据")
    public void selectAll() throws ParseException {

        // 获取token
        getToken();

        //巡查任务周期id
        RwzqUuidResponse rwzqUuidResponse = aSafeRwzqService.getXcUuid();
        String rwzqUuid = rwzqUuidResponse.getXxbh();
        String responseList = HttpRequest.post(imUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject jsonResponseList = JSON.parseObject(responseList);
        logger.info(responseList);
        String dataList = jsonResponseList.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            logger.info("dataList没有数据");
            return;
        }
        logger.info(dataList);
        List<ACheckQuatzRequest> list = JSON.parseArray(dataList, ACheckQuatzRequest.class);
        if (CollectionUtil.isEmpty(list)) {
            logger.info("list没有数据");
            logger.info(list.toString());
            return;
        }
        for (ACheckQuatzRequest a : list) {
            //获取企业编号
            ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(a.getName(), a.getEntCode());
            String enterPriseId = "";
            if (aSafeQyjcxx == null) {
                continue;
            } else {
                enterPriseId = aSafeQyjcxx.getXxbh();
            }

            // todo 查询巡查任务主表2月是否有记录就不推
            Integer xcrwNum = aSafeXcrwService.xcrwNum(enterPriseId);
            if (xcrwNum > 0) {
                logger.info("查任务主表2月是否有记录就不推");
                continue;
            }
            // todo 来自新表查询 根据企业xxbh 以及周期编号
            JSONObject xcjsonObject = new JSONObject();
            xcjsonObject.put("qybh", aSafeQyjcxx.getXxbh());
            xcjsonObject.put("zqbh", rwzqUuid);
            String xcresponse = HttpRequest.post(xczqUrl)
                    .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                    .header("Authorization", token)
                    .body(xcjsonObject.toJSONString())
                    .execute().body();
            JSONObject xcjsonResponse = JSON.parseObject(xcresponse);
            if (xcjsonResponse.getString("msg") == null) {
                continue;
            }
            String xcrwuuid = xcjsonResponse.getString("msg");

            //根据工单获取数据
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("improvingNo", a.getImprovingNo());
            String response = HttpRequest.post(url)
                    .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                    .header("Authorization", token)
                    .body(jsonObject.toJSONString())
                    .execute().body();
            JSONObject jsonResponse = JSON.parseObject(response);
            // 提取数据
            String data = jsonResponse.getString("data");
            JSONObject json = JSONObject.parseObject(data);
            Object zgqtpListObj = json.get("zgqtpList");
            Object zghtpListObj = json.get("zghtpList");
            String zgqtpListStr = JSONObject.toJSONString(zgqtpListObj);
            String zghtpListStr = JSONObject.toJSONString(zghtpListObj);
            List<ACheckXcTpResponse> zgqTpList = JSON.parseArray(zgqtpListStr, ACheckXcTpResponse.class);
            List<ACheckXcTpResponse> zghtpList = JSON.parseArray(zghtpListStr, ACheckXcTpResponse.class);
            int xxsx = 0;
            /**
             * 附件表a_safe_rwfj
             */
            for (ACheckXcTpResponse zgq : zgqTpList) {
                /**
                 * 新增整改前任务附件
                 */
                saveZgqTp(zgq, xcrwuuid, xxsx);
            }

            for (ACheckXcTpResponse zgh : zghtpList) {
                /**
                 * 新增整改后任务附件
                 */
                svaeZghTp(zgh, xcrwuuid, xxsx);
            }

//            /**
//             *新增任务周期a_safe_rwzq
//             */
//            saveRwzq(a, rwzqUuid);
            /**
             *  新增巡查信息表 a_safe_xcrw
             */
            try {
                saveXcrw(list, a, xcrwuuid, enterPriseId, rwzqUuid);
            } catch (Exception e) {
                continue;
            }


            for (ACheckQuatzEntity b : a.getList()) {
                String xcrwjcxUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String xcrwjcxzgxxUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String xcrwwzUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String yhzgxxUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();

                /**
                 * 巡查任务位置 a_safe_xcrwwz
                 */
                saveXcrwwz(b, xcrwwzUuid, xcrwuuid, rwzqUuid);

                /**
                 * 巡查风险点位置隐患 a_safe_yhzgxx
                 */
                saveYhzgxx(list, a, b, yhzgxxUuid, xcrwuuid, enterPriseId, rwzqUuid, xcrwwzUuid);

                /**
                 * 巡查任务检查项记录 a_safe_xcrwjcx
                 */
                saveXcrwJcx(b, xcrwjcxUuid, yhzgxxUuid, xcrwwzUuid, enterPriseId, xcrwuuid, rwzqUuid);

                /**
                 * 巡查任务隐患整改/隐患复查 a_safe_xcrwjcxzgxx
                 */
                saveXcrwJcxZgxx(a, b, xcrwjcxzgxxUuid, xcrwuuid, xcrwjcxUuid, rwzqUuid);

            }
        }
    }

    /**
     * @param list
     * @param a            定时任务巡查请求类
     * @param b            定时任务实体类
     * @param yhzgxxUuid   风险点隐患id
     * @param xcrwuuid     巡查任务id
     * @param enterPriseId 企业id
     * @param rwzqUuid     任务周期id
     * @param xcrwwzUuid   巡查任务位置id
     */
    private void saveYhzgxx(List<ACheckQuatzRequest> list, ACheckQuatzRequest a, ACheckQuatzEntity b, String yhzgxxUuid, String xcrwuuid, String enterPriseId, String rwzqUuid, String xcrwwzUuid) {
        ASafeYhzgxx aSafeYhzgxx = new ASafeYhzgxx();
        //信息编号
        aSafeYhzgxx.setXxbh(yhzgxxUuid);
        //任务编号
        aSafeYhzgxx.setRwbh(xcrwuuid);
        //位置编号
        aSafeYhzgxx.setWzbh(b.getWzxxbh());
        //企业编号
        aSafeYhzgxx.setQybh(enterPriseId);
        //周期编号
        aSafeYhzgxx.setZqbh(rwzqUuid);
        //企业风险点编号 对应a_safe_fxd的信息编号
        if (b.getFxdxxbh() == null) {
            aSafeYhzgxx.setQyfxdbh("03_20240617093239130405");
        } else {
            aSafeYhzgxx.setQyfxdbh(b.getFxdxxbh());
        }
        //隐患来源
        aSafeYhzgxx.setYhly("1");
        //检查时间
        aSafeYhzgxx.setJcsj(a.getReportDateTime());
        //整改期限
        aSafeYhzgxx.setZgqx(b.getNeedFinalDateTime());
        //不合格检查项a_safe_xcrwjcx中JCXJG=1的数量
        aSafeYhzgxx.setBhgjcx(list.size());
        //是否展示
        aSafeYhzgxx.setSfzs(1);
        //巡查位置编号
        aSafeYhzgxx.setXcwzbh(xcrwwzUuid);
        //复查是否合格
        aSafeYhzgxx.setFcsfhg(1);
        //隐患描述
        aSafeYhzgxx.setYhms(b.getDescription());
        //整改结果
        aSafeYhzgxx.setZgjg("已完成");
        //历史逾期
        aSafeYhzgxx.setLsyq(0);
        //整改时间
        aSafeYhzgxx.setZgsj(b.getReportDateTime());
        //完成状态
        aSafeYhzgxx.setWczt(1);
        //整改状态
        aSafeYhzgxx.setZgzt(1);
        //入库人员
        aSafeYhzgxx.setRkry(b.getRybh());
        //入库时间
        aSafeYhzgxx.setRksj(new Date());
        //更新人员
        aSafeYhzgxx.setGxry(b.getRybh());
        //更新时间
        aSafeYhzgxx.setGxsj(new Date());
        //记录状态
        aSafeYhzgxx.setJlzt(1);
        aSafeYhzgxxService.save(aSafeYhzgxx);
    }

    /**
     * @param b          定时任务实体类
     * @param xcrwwzUuid 巡查任务位置ido
     * @param xcrwuuid   巡查任务id
     * @param rwzqUuid   任务周期id
     */
    private void saveXcrwwz(ACheckQuatzEntity b, String xcrwwzUuid, String xcrwuuid, String rwzqUuid) {
        ASafeXcrwwz aSafeXcrwwz = new ASafeXcrwwz();
        //xxbh
        aSafeXcrwwz.setXxbh(xcrwwzUuid);
        //任务编号
        aSafeXcrwwz.setRwbh(xcrwuuid);
        //位置编号
        aSafeXcrwwz.setWzbh(b.getWzxxbh());
        //位置名称
        aSafeXcrwwz.setWzmc(b.getWzmc());
        //周期编号
        aSafeXcrwwz.setZqbh(rwzqUuid);
        //完成状态
        aSafeXcrwwz.setWczt(1);
        //入库时间
        aSafeXcrwwz.setRksj(new Date());
        //更新时间
        aSafeXcrwwz.setGxsj(new Date());
        //记录状态
        aSafeXcrwwz.setJlzt(1);
        aSafeXcrwwzService.save(aSafeXcrwwz);
    }

    /**
     * @param a               定时任务巡查请求类
     * @param b               定时任务实体类
     * @param xcrwjcxzgxxUuid 巡查任务检查项整改id
     * @param xcrwuuid        巡查任务id
     * @param xcrwjcxUuid     巡查任务检查项id
     * @param rwzqUuid        任务周期id
     */
    private void saveXcrwJcxZgxx(ACheckQuatzRequest a, ACheckQuatzEntity b, String xcrwjcxzgxxUuid, String xcrwuuid, String xcrwjcxUuid, String rwzqUuid) {
        ASafeXcrwjcxzgxx aSafeXcrwjcxzgxx = new ASafeXcrwjcxzgxx();
        //信息编号
        aSafeXcrwjcxzgxx.setXxbh(xcrwjcxzgxxUuid);
        //任务编号对应a_safe_xcrw的信息编号
        aSafeXcrwjcxzgxx.setRwbh(xcrwuuid);
        //描述 content
        aSafeXcrwjcxzgxx.setMs(b.getContent());
        //巡查检查项编号 a_safe_xcrwjcx的XXBH
        aSafeXcrwjcxzgxx.setXcjcxbh(xcrwjcxUuid);
        //时间
        aSafeXcrwjcxzgxx.setSj(a.getFinalDateTime());
        //类型
        aSafeXcrwjcxzgxx.setSjlx("ZG");
        //是否合格
        aSafeXcrwjcxzgxx.setSfhg(1);
        //到期日期
        aSafeXcrwjcxzgxx.setDqrq(b.getNeedFinalDateTime());
        //周期编号
        aSafeXcrwjcxzgxx.setZqbh(rwzqUuid);
        //入库人员
        aSafeXcrwjcxzgxx.setRkry(b.getRybh());
        //入库时间
        aSafeXcrwjcxzgxx.setRksj(new Date());
        //更新人员
        aSafeXcrwjcxzgxx.setGxry(b.getRybh());
        //更新时间
        aSafeXcrwjcxzgxx.setGxsj(new Date());
        //记录状态
        aSafeXcrwjcxzgxx.setJlzt(1);
        aSafeXcrwjcxzgxxService.save(aSafeXcrwjcxzgxx);
    }

    /**
     * @param b            定时任务实体类
     * @param xcrwjcxUuid  巡查任务检查项id
     * @param enterPriseId 企业id
     * @param xcrwuuid     巡查任务id
     * @param rwzqUuid     任务周期id
     */
    private void saveXcrwJcx(ACheckQuatzEntity b, String xcrwjcxUuid, String yhzgxxUuid, String xcrwwzUuid, String enterPriseId, String xcrwuuid, String rwzqUuid) {
        ASafeXcrwjcx aSafeXcrwjcx = new ASafeXcrwjcx();
        //信息编号
        aSafeXcrwjcx.setXxbh(xcrwjcxUuid);
        //企业编号
        aSafeXcrwjcx.setQybh(enterPriseId);
        //任务编号对应a_safe_xcrw的信息编号
        aSafeXcrwjcx.setRwbh(xcrwuuid);
        //企业风险点编号 对应a_safe_fxd的信息编号
        //todo
        if (b.getFxdxxbh() == null) {
            aSafeXcrwjcx.setQyfxdbh("03_20240617093239130405");
        } else {
            aSafeXcrwjcx.setQyfxdbh(b.getFxdxxbh());
        }

        //周期编号
        aSafeXcrwjcx.setZqbh(rwzqUuid);
        //完成状态
        aSafeXcrwjcx.setWczt(1);
        //检查项结果
        aSafeXcrwjcx.setJcxjg(String.valueOf(1));
        //隐患描述
        aSafeXcrwjcx.setYhms(b.getDescription());
        //检查时间
        aSafeXcrwjcx.setJcsj(b.getReportDateTime());
        //整改时间
        aSafeXcrwjcx.setZgsj(b.getFinalDateTime());
        //整改描述
        aSafeXcrwjcx.setZgms(b.getContent());
        //整改期限
        aSafeXcrwjcx.setZgqx(b.getNeedFinalDateTime());
        //整改状态
        aSafeXcrwjcx.setZgzt(1);
        //整改逾期
        aSafeXcrwjcx.setZgyq(0);
        //复查时间
        aSafeXcrwjcx.setFcsj(b.getReviewDateTime());
        //复查是否合格
        aSafeXcrwjcx.setFcsfhg(1);
        //复查期限
        aSafeXcrwjcx.setFcqx(b.getReviewDateTime());
        //复查逾期
        aSafeXcrwjcx.setFcyq(0);
        //复查状态
        aSafeXcrwjcx.setFczt(1);
        //是否重点检查项
        aSafeXcrwjcx.setSfzdjcx(1);
        //检查要点
        aSafeXcrwjcx.setJcyd(b.getJcydId());
        //是否展示
        aSafeXcrwjcx.setSfzs(1);
        //历史整改逾期
        aSafeXcrwjcx.setLszgyq(0);
        //复查历史逾期
        aSafeXcrwjcx.setFclsyq(0);
        //复查信息
        aSafeXcrwjcx.setFcxx(b.getReviewContent());
        //位置编号
        aSafeXcrwjcx.setWzbh(xcrwuuid);
        //巡查位置编号
        aSafeXcrwjcx.setXcwzbh(xcrwwzUuid);
        //巡查风险点编号
        aSafeXcrwjcx.setXcfxdbh(b.getFxdxxbh());
        //任务类型
        aSafeXcrwjcx.setRwlx(3);
        //入库人员
        aSafeXcrwjcx.setRkry(b.getRybh());
        //入库时间
        aSafeXcrwjcx.setRksj(new Date());
        //更新人员
        aSafeXcrwjcx.setGxry(b.getRybh());
        //更新时间
        aSafeXcrwjcx.setGxsj(new Date());
        //记录状态
        aSafeXcrwjcx.setJlzt(1);
        aSafeXcrwjcxService.save(aSafeXcrwjcx);
    }

    /**
     * @param list         定时任务巡查请求类list
     * @param a            定时任务巡查请求类
     * @param xcrwuuid     巡查任务id
     * @param enterPriseId 企业id
     * @param rwzqUuid     任务周期id
     */
    private void saveXcrw(List<ACheckQuatzRequest> list, ACheckQuatzRequest a, String xcrwuuid, String enterPriseId, String rwzqUuid) {
        ASafeXcrw aSafeXcrw = new ASafeXcrw();
        //信息编号
        aSafeXcrw.setXxbh(xcrwuuid);
        //企业编号
        aSafeXcrw.setQybh(enterPriseId);
        //任务类型
        aSafeXcrw.setRwlx("WGXC");
        //巡查项
        aSafeXcrw.setXcx(list.size());
        //完成项
        aSafeXcrw.setWcx(list.size());
        //发现隐患数
        aSafeXcrw.setFxyhs(list.size());
        //检查时间
        if (a.getReportDateTime() != null) {
            aSafeXcrw.setJcsj(a.getReportDateTime());
        } else {
            aSafeXcrw.setJcsj(null);
        }
        //任务周期
        aSafeXcrw.setZqbh(rwzqUuid);
        //完成状态
        aSafeXcrw.setWczt(1);
        //入库人员
        aSafeXcrw.setRkry(a.getRybh());
        //入库时间
        aSafeXcrw.setRksj(new Date());
        //更新时间
        aSafeXcrw.setGxsj(new Date());
        //更新人员
        aSafeXcrw.setGxry(a.getRybh());
        //记录状态
        aSafeXcrw.setJlzt(1);
        //新增
        aSafeXcrwService.save(aSafeXcrw);
    }

    /**
     * @param a        定时任务巡查请求类
     * @param rwzqUuid 任务周期id
     */

    private void saveRwzq(ACheckQuatzRequest a, String rwzqUuid) {
        ASafeRwzq aSafeRwzq = new ASafeRwzq();
        //信息编号
        aSafeRwzq.setXxbh(rwzqUuid);
        //周期开始时间
        aSafeRwzq.setZqkssj(a.getReportDateTime());
        //周期结束时间
        aSafeRwzq.setZqjssj(a.getFinalDateTime());
        //任务类型,QYZC,WGXC,AJB,JNRY
        aSafeRwzq.setRwlx("WGXC");
        aSafeRwzq.setGxsj(new Date());
        aSafeRwzq.setRksj(new Date());
        aSafeRwzqService.save(aSafeRwzq);
    }

    /**
     * @param zgq      图片响应类
     * @param xcrwuuid 巡查任务id
     * @param xxsx     显示顺序
     * @throws ParseException
     */
    private void saveZgqTp(ACheckXcTpResponse zgq, String xcrwuuid, int xxsx) throws ParseException {
        String rwfjUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
        ASafeRwfj aSafeRwfj = new ASafeRwfj();
        aSafeRwfj.setXxbh(rwfjUuid);
        //附件名称
        aSafeRwfj.setFjmc(zgq.getFileName());
        //附件后缀
        aSafeRwfj.setFjhz(zgq.getContentType());
        //关联父级编号
        aSafeRwfj.setPid(xcrwuuid);
        //附件地址
        aSafeRwfj.setFjdz(api + zgq.getRelativePath());
        //文件类型
        aSafeRwfj.setWjlx("ZGQTP");
        //显示顺序
        aSafeRwfj.setXssx(xxsx++);
        //记录状态
        aSafeRwfj.setJlzt(1);
        //入库人员
        aSafeRwfj.setRkry(zgq.getAddUserName());
        //入库时间
        String dateString = zgq.getAddDateTime();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = format.parse(dateString);
        aSafeRwfj.setRksj(date);
        //更新时间
        aSafeRwfj.setGxsj(date);
        //更新人员
        aSafeRwfj.setGxry(zgq.getAddUserName());
        aSafeRwfjService.save(aSafeRwfj);

    }

    /**
     * @param zgh      图片响应类
     * @param xcrwuuid 巡查任务id
     * @param xxsx     显示顺序
     * @throws ParseException
     */
    private void svaeZghTp(ACheckXcTpResponse zgh, String xcrwuuid, int xxsx) throws ParseException {
        String rwfjUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
        ASafeRwfj aSafeRwfj = new ASafeRwfj();

        aSafeRwfj.setXxbh(rwfjUuid);
        //附件名称
        aSafeRwfj.setFjmc(zgh.getFileName());
        //附件后缀
        aSafeRwfj.setFjhz(zgh.getContentType());
        //关联父级编号
        aSafeRwfj.setPid(xcrwuuid);
        //附件地址
        aSafeRwfj.setFjdz(api + zgh.getRelativePath());
        //文件类型
        aSafeRwfj.setWjlx("ZGHTP");
        //记录状态
        aSafeRwfj.setJlzt(1);
        //显示顺序
        aSafeRwfj.setXssx(xxsx++);
        //入库人员
        aSafeRwfj.setRkry(zgh.getAddUserName());
        //入库时间
        String dateString = zgh.getAddDateTime();
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = format.parse(dateString);
        aSafeRwfj.setRksj(date);
        //更新时间
        aSafeRwfj.setGxsj(date);
        //更新人员
        aSafeRwfj.setGxry(zgh.getAddUserName());
        aSafeRwfjService.save(aSafeRwfj);

    }


    @Scheduled(cron = "0 0 4 * * ? ")
//    @Scheduled(cron = "0 0/5 * * * ?")
//    @PostMapping("/zicha")
//    @ApiOperation(value = "自查")
    public void zicha() throws ParseException {
        // 获取token
        getToken();
        //自己查任务周期id
        RwzqUuidResponse rwzqUuidResponse = aSafeRwzqService.getZcUuid();
        String rwzqUuid = rwzqUuidResponse.getXxbh();
        String responseList = HttpRequest.post(zcXxUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject jsonResponseList = JSON.parseObject(responseList);
        String dataList = jsonResponseList.getString("data");
        logger.info(JSONUtil.toJsonStr(responseList));
        if (StrUtil.isEmpty(dataList)) {
            logger.info("dataList没有数据");
            return;
        }
        List<ACheckQuatzZichaRequest> list = JSON.parseArray(dataList, ACheckQuatzZichaRequest.class);
        if (CollectionUtil.isEmpty(list)) {
            return;
        }
        for (ACheckQuatzZichaRequest a : list) {
            // todo 查询自查任务主表本月是否有记录 有就不推
            Integer zcrwNum = aSafeZcrwService.zcrwNum(a.getEnterpriseID());
            if (zcrwNum > 0) {
                logger.info("查询自查任务主表本月是否有记录 有就不推");
                continue;
            }
            if (a.getEnterpriseID() == null) {
                logger.info("getEnterpriseID为空");
                continue;
            }
            JSONObject zcjsonObject = new JSONObject();
            zcjsonObject.put("qybh", a.getEnterpriseID());
            zcjsonObject.put("zqbh", rwzqUuid);
            logger.info(JSONUtil.toJsonStr(zcjsonObject));
            String zcresponse = HttpRequest.post(zczqUrl)
                    .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                    .header("Authorization", token)
                    .body(zcjsonObject.toJSONString())
                    .execute().body();
            JSONObject zcjsonResponse = JSON.parseObject(zcresponse);
            logger.info(JSONUtil.toJsonStr(zcjsonResponse));
            if (zcjsonResponse.getString("msg") == null) {
                continue;
            }
            String zcrwUuid = zcjsonResponse.getString("msg");

            /**
             *新增任务周期a_safe_rwzq
             */
            //    saveRwzq(a, rwzqUuid);
            /**
             * 自查任务 a_safe_zcrw
             */
            saveZcrw(a, zcrwUuid, rwzqUuid);
            for (ACheckQuatzZichaEntity b : a.getList()) {
                String zcrwjlUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String zcrwwzUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String zcyhxxUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                String yhzgxxUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
                /**
                 * 附件表a_safe_rwfj
                 */
                //根据工单获取数据
                JSONObject jsonObject = new JSONObject();
                jsonObject.put("imageRelationID", b.getImgId());
                String response = HttpRequest.post(zcUrl)
                        .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                        .header("Authorization", token)
                        .body(jsonObject.toJSONString())
                        .execute().body();
                JSONObject jsonResponse = JSON.parseObject(response);
                // 提取数据
                String data = jsonResponse.getString("data");
                JSONObject json = JSONObject.parseObject(data);
                Object zgqtpListObj = json.get("zcList");
                String zgqtpListStr = JSONObject.toJSONString(zgqtpListObj);
                int xxsx = 0;
                List<ACheckXcTpResponse> zgqTpList = JSON.parseArray(zgqtpListStr, ACheckXcTpResponse.class);
                for (ACheckXcTpResponse zc : zgqTpList) {
                    /**
                     * 自查整改前图片
                     */
                    saveZczgqTp(zc, zcrwUuid, xxsx);
                }
                /**
                 *自查任务位置表a_safe_zcrwwz
                 */
                saveZcRwwz(a, b, zcrwwzUuid, zcrwUuid, rwzqUuid);
                /**
                 * 自查任务检查项记录 a_safe_zcrwjl
                 */
                saveZcrwjl(b, zcrwjlUuid, zcrwUuid, rwzqUuid, zcrwwzUuid);
                /**
                 * 自查任务隐患/整改 szs_a_safe_zcyhxx同巡查信息
                 */
                saveZcyHxx(a, b, zcyhxxUuid, zcrwUuid, zcrwjlUuid, rwzqUuid);
                /**
                 * 自查风险点位置隐患 a_safe_yhzgxx
                 */
                saveZihaYhzgxx(list, a, b, yhzgxxUuid, zcrwUuid, rwzqUuid, zcrwUuid);
            }
        }
    }

    /**
     * @param a          定时任务自查请求类
     * @param b          定时任务自查实体类
     * @param zcyhxxUuid 自查任务隐患id
     * @param zcrwUuid   自查任务id
     * @param zcrwjlUuid 自查任务记录id
     * @param rwzqUuid   任务周期id
     */
    private void saveZcyHxx(ACheckQuatzZichaRequest a, ACheckQuatzZichaEntity b, String zcyhxxUuid, String zcrwUuid, String zcrwjlUuid, String rwzqUuid) {
        SzsASafeZcyhxx szsASafeZcyhxx = new SzsASafeZcyhxx();
        //信息编号
        szsASafeZcyhxx.setXxbh(zcyhxxUuid);
        //任务编号对应a_safe_xcrw的信息编号
        szsASafeZcyhxx.setRwbh(zcrwUuid);
        //描述 content
        szsASafeZcyhxx.setMs(b.getContent());
        //巡查检查项编号 a_safe_xcrwjcx的XXBH
        szsASafeZcyhxx.setXcjcxbh(zcrwjlUuid);
        //时间
        szsASafeZcyhxx.setSj(a.getReportDateTime());
        //类型
        szsASafeZcyhxx.setSjlx("FC");
        //是否合格
        szsASafeZcyhxx.setSfhg(1);

        //周期编号
        szsASafeZcyhxx.setZqbh(rwzqUuid);
        //入库人员
        szsASafeZcyhxx.setRkry(b.getAddUserID());
        //入库时间
        szsASafeZcyhxx.setRksj(new Date());
        //更新人员
        szsASafeZcyhxx.setGxry(b.getAddUserID());
        //更新时间
        szsASafeZcyhxx.setGxsj(new Date());
        //记录状态
        szsASafeZcyhxx.setJlzt(1);
        szsASafeZcyhxxService.save(szsASafeZcyhxx);
    }

    /**
     * @param b          定时任务自查实体类
     * @param zcrwjlUuid 自查任务记录id
     * @param zcrwUuid   自查任务id
     * @param rwzqUuid   任务周期id
     * @param zcrwwzUuid 自查任务位置id
     */
    private void saveZcrwjl(ACheckQuatzZichaEntity b, String zcrwjlUuid, String zcrwUuid, String rwzqUuid, String zcrwwzUuid) {
        ASafeZcrwjl aSafeZcrwjl = new ASafeZcrwjl();
        //信息编号
        aSafeZcrwjl.setXxbh(zcrwjlUuid);
        //企业编号
        aSafeZcrwjl.setQybh(b.getEnterpriseID());
        //任务编号
        aSafeZcrwjl.setRwbh(zcrwUuid);
        //企业风险点编号
        if (b.getFxdxxbh() == null) {
            aSafeZcrwjl.setQyfxdbh("03_20240617093239130405");
        } else {
            aSafeZcrwjl.setQyfxdbh(b.getFxdxxbh());
        }
        //企业风险点位置编号
        aSafeZcrwjl.setQyfxdwzbh(b.getFxbh());
        //是否发现隐患
        aSafeZcrwjl.setSffxyh(0);
        //完成状态
        aSafeZcrwjl.setWczt(1);
        //检查时间
        aSafeZcrwjl.setJcsj(b.getAddDateTime());
        //周期编号
        aSafeZcrwjl.setZqbh(rwzqUuid);
        //位置编号
        aSafeZcrwjl.setWzbh(b.getWzbh());
        //自查任务位置编号
        aSafeZcrwjl.setZcrwwzbh(zcrwwzUuid);
        //设备数量
        aSafeZcrwjl.setSbsl(b.getSbsl());
        //检查状态
        aSafeZcrwjl.setJczt(1);
        //是否检查
        aSafeZcrwjl.setSfjc(1);
        //是否采取有限管控措施
        aSafeZcrwjl.setSfcqyxgkcs(1);
        //隐患描述
        aSafeZcrwjl.setYhms(b.getContent());
        //记录状态
        aSafeZcrwjl.setJlzt(1);
        //入库人员
        aSafeZcrwjl.setRkry(b.getAddUserID());
        //入库时间
        aSafeZcrwjl.setRksj(new Date());
        //更新人员
        aSafeZcrwjl.setGxry(b.getAddUserID());
        //更新时间
        aSafeZcrwjl.setGxsj(new Date());
        // 完成状态
        aSafeZcrwjl.setWczt(1);
        aSafeZcrwjlService.save(aSafeZcrwjl);
    }

    /**
     * @param a          定时任务自查请求类
     * @param b          定时任务自查实体类
     * @param zcrwwzUuid 自查任务位置id
     * @param zcrwUuid   自查任务id
     * @param rwzqUuid   任务周期id
     */
    private void saveZcRwwz(ACheckQuatzZichaRequest a, ACheckQuatzZichaEntity b, String zcrwwzUuid, String zcrwUuid, String rwzqUuid) {
        ASafeZcrwwz aSafeZcrwwz = new ASafeZcrwwz();
        //信息编号
        aSafeZcrwwz.setXxbh(zcrwwzUuid);
        //企业编号
        aSafeZcrwwz.setQybh(a.getEnterpriseID());
        //任务编号
        aSafeZcrwwz.setRwbh(zcrwUuid);
        //周期编号
        aSafeZcrwwz.setZqbh(rwzqUuid);
        //市风险点编号
        aSafeZcrwwz.setSfxdbh(b.getSfxdbh());
        //位置编号
        aSafeZcrwwz.setWzbh(b.getWzbh());
        //入库人员
        aSafeZcrwwz.setRkry(b.getAddUserID());
        //入库时间
        aSafeZcrwwz.setRksj(new Date());
        //更新时间
        aSafeZcrwwz.setGxsj(new Date());
        //更新人员
        aSafeZcrwwz.setGxry(b.getAddUserID());
        aSafeZcrwwz.setJlzt(1);
        aSafeZcrwwzService.save(aSafeZcrwwz);
    }

    /**
     * @param zc       图片响应类
     * @param zcrwUuid 自查任务id
     * @param xxsx     显示顺序
     * @throws ParseException
     */
    private void saveZczgqTp(ACheckXcTpResponse zc, String zcrwUuid, int xxsx) throws ParseException {
        String rwfjUuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
        ASafeRwfj aSafeRwfj = new ASafeRwfj();
        aSafeRwfj.setXxbh(rwfjUuid);
        //附件名称
        aSafeRwfj.setFjmc(zc.getFileName());
        //附件后缀
        aSafeRwfj.setFjhz(zc.getContentType());
        //关联父级编号
        aSafeRwfj.setPid(zcrwUuid);
        //附件地址
        aSafeRwfj.setFjdz(api + zc.getRelativePath());
        //文件类型
        aSafeRwfj.setWjlx("ZGQTP");
        //记录状态
        aSafeRwfj.setJlzt(1);
        //入库人员
        aSafeRwfj.setRkry(zc.getAddUserName());
        //入库时间
        String dateString = zc.getAddDateTime();
        SimpleDateFormat zcformat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date zcdate = zcformat.parse(dateString);
        aSafeRwfj.setRksj(zcdate);
        //显示顺序
        aSafeRwfj.setXssx(xxsx++);
        //更新时间
        aSafeRwfj.setGxsj(zcdate);
        //更新人员
        aSafeRwfj.setGxry(zc.getAddUserName());
        aSafeRwfjService.save(aSafeRwfj);

    }

    /**
     * @param a        定时任务自查请求类
     * @param zcrwUuid 自查任务id
     * @param rwzqUuid 任务周期id
     */
    private void saveZcrw(ACheckQuatzZichaRequest a, String zcrwUuid, String rwzqUuid) {
        ASafeZcrw aSafeZcrw = new ASafeZcrw();
        aSafeZcrw.setXxbh(zcrwUuid);
        //企业编号
        aSafeZcrw.setQybh(a.getEnterpriseID());
        //自查项
        aSafeZcrw.setZcx(a.getList().size());
        //完成项
        aSafeZcrw.setWcx(a.getList().size());
        //周期编号
        aSafeZcrw.setZqbh(rwzqUuid);
        //发现隐患数
        aSafeZcrw.setFxyhs(a.getList().size());
        //完成状态
        aSafeZcrw.setWczt(1);
        //入库人员
        aSafeZcrw.setRkry(a.getAddUserID());
        //入库时间
        aSafeZcrw.setRksj(new Date());
        //更新时间
        aSafeZcrw.setGxsj(new Date());
        //更新人员
        aSafeZcrw.setGxry(a.getAddUserID());
        aSafeZcrw.setJlzt(1);

        aSafeZcrwService.save(aSafeZcrw);
    }

    /**
     * @param a        定时任务自查请求类
     * @param rwzqUuid 任务周期id
     */
    private void saveRwzq(ACheckQuatzZichaRequest a, String rwzqUuid) {
        ASafeRwzq aSafeRwzq = new ASafeRwzq();
        //信息编号
        aSafeRwzq.setXxbh(rwzqUuid);
        //周期开始时间
        aSafeRwzq.setZqkssj(a.getReportDateTime());
        //周期结束时间
        aSafeRwzq.setZqjssj(a.getEndDateTime());
        //任务类型,QYZC,WGXC,AJB,JNRY
        aSafeRwzq.setRwlx("QYZC");
        aSafeRwzq.setGxsj(new Date());
        aSafeRwzq.setRksj(new Date());
        aSafeRwzqService.save(aSafeRwzq);
    }


    /**
     * @param list
     * @param a          定时任务巡查请求类
     * @param b          定时任务实体类
     * @param yhzgxxUuid 风险点隐患id
     * @param rwzqUuid   任务周期id
     * @param xcrwwzUuid 巡查任务位置id
     */
    private void saveZihaYhzgxx(List<ACheckQuatzZichaRequest> list, ACheckQuatzZichaRequest a, ACheckQuatzZichaEntity b, String yhzgxxUuid, String zcrwUuid, String rwzqUuid, String xcrwwzUuid) {
        ASafeYhzgxx aSafeYhzgxx = new ASafeYhzgxx();
        //信息编号
        aSafeYhzgxx.setXxbh(yhzgxxUuid);
        //任务编号
        aSafeYhzgxx.setRwbh(zcrwUuid);
        //位置编号
        aSafeYhzgxx.setWzbh(b.getWzbh());
        //企业编号
        aSafeYhzgxx.setQybh(b.getEnterpriseID());
        //周期编号
        aSafeYhzgxx.setZqbh(rwzqUuid);
        //企业风险点编号 对应a_safe_fxd的信息编号
        if (b.getFxdxxbh() == null) {
            aSafeYhzgxx.setQyfxdbh("03_20240617093239130405");
        } else {
            aSafeYhzgxx.setQyfxdbh(b.getFxdxxbh());
        }
        //隐患来源
        aSafeYhzgxx.setYhly("2");
        //检查时间
        aSafeYhzgxx.setJcsj(a.getReportDateTime());
        //整改期限
        // aSafeYhzgxx.setZgqx(b.getNeedFinalDateTime());
        //不合格检查项a_safe_xcrwjcx中JCXJG=1的数量
        aSafeYhzgxx.setBhgjcx(list.size());
        //是否展示
        aSafeYhzgxx.setSfzs(1);
        //巡查位置编号
        aSafeYhzgxx.setXcwzbh(xcrwwzUuid);
        //复查是否合格
        aSafeYhzgxx.setFcsfhg(1);
        //隐患描述
        aSafeYhzgxx.setYhms(b.getContent());
        //整改结果
        aSafeYhzgxx.setZgjg("已完成");
        //历史逾期
        aSafeYhzgxx.setLsyq(0);
        //整改时间
        aSafeYhzgxx.setZgsj(b.getReportDateTime());
        //完成状态
        aSafeYhzgxx.setWczt(1);
        //整改状态
        aSafeYhzgxx.setZgzt(1);
        //入库人员
        // aSafeYhzgxx.setRkry(b.getRybh());
        //入库时间
        aSafeYhzgxx.setRksj(new Date());
        //更新人员
        //  aSafeYhzgxx.setGxry(b.getRybh());
        //更新时间
        aSafeYhzgxx.setGxsj(new Date());
        //记录状态
        aSafeYhzgxx.setJlzt(1);
        aSafeYhzgxxService.save(aSafeYhzgxx);
    }


    /**
     * 停复工表
     */
    @Scheduled(cron = "0 0 4 * * ? ")
//    @Scheduled(cron = "0 0/5 * * * ?")
//    @PostMapping("/tfg")
//    @ApiOperation(value = "停复工表")
    public void tfg() {
        // 获取token
        getToken();
        //当前时间
        Date currentDate = new Date();
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String currentTimeString = dateFormat.format(currentDate);
        //停复工表推送
        String responseList = HttpRequest.get(tfgUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject jsonResponseList = JSON.parseObject(responseList);
        String dataList = jsonResponseList.getString("rows");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        //获取企业编号
        List<ASafeTfg> tfgList = JSON.parseArray(dataList, ASafeTfg.class);
        for (ASafeTfg a : tfgList) {
            ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(a.getQymc(), a.getTyshxydm());
            String enterPriseId = aSafeQyjcxx.getXxbh();
            String tyshxydm = aSafeQyjcxx.getTyshxybm();
            a.setQybh(enterPriseId);
            a.setTyshxydm(tyshxydm);
            aSafeTfgService.save(a);
            //停复工审核表推送
            saveAsafeTfg(a, currentTimeString);
        }


    }

    /**
     * 停复工审核表推送
     *
     * @param a                 停工推送信息
     * @param currentTimeString 当前时间
     */
    private void saveAsafeTfg(ASafeTfg a, String currentTimeString) {
        ASafeTfgsh aSafeTfgsh = new ASafeTfgsh();
        aSafeTfgsh.setTfgbh(a.getXxbh());
        aSafeTfgsh.setShsj(currentTimeString);
        aSafeTfgsh.setShjg(String.valueOf(1));
        aSafeTfgsh.setJlzt(1);
        aSafeTfgsh.setGxsj(new Date());
        aSafeTfgsh.setGxry(a.getGxry());
        aSafeTfgsh.setRksj(new Date());
        aSafeTfgsh.setRkry(a.getRkry());
        aSafeTfgshService.save(aSafeTfgsh);
    }
}
