package com.mudu.quartz;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.mudu.entity.ASafeBqbhpx;
import com.mudu.entity.ASafeQyjcxx;
import com.mudu.entity.ASafeQyzypgl;
import com.mudu.entity.dto.request.ASafeBqbhpxRequest;
import com.mudu.entity.dto.request.ASafeQyzypglRequest;
import com.mudu.entity.dto.response.EnterpriseResponse;
import com.mudu.entity.dto.response.XcTpResponse;
import com.mudu.service.ASafeBqbhpxService;
import com.mudu.service.ASafeQyjcxxService;
import com.mudu.service.ASafeQyzypglService;
import com.mudu.service.EnterpriseService;
import com.mudu.service.impl.LoginService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 班前班后以及特殊作业的数据接收
 *
 * @author wu
 * @since 2024/4/26 下午4:40
 */
//@RestController
//@RequestMapping("mudu/test")
//@Api(tags = "班前班后以及特殊作业的数据接收")
@Transactional(rollbackFor = Exception.class)
@Configuration
@EnableScheduling
public class BqbhTszyQuartz {
    @Resource
    private LoginService loginService;
    @Resource
    private ASafeBqbhpxService safeBqbhpxService;

    @Resource
    private ASafeQyzypglService safeQyzypglService;

    @Resource
    private ASafeQyjcxxService aSafeQyjcxxService;

    @Resource
    private EnterpriseService enterpriseService;

    @Value("${bqbhUrl}")
    private String bqbhUrl;

    @Value("${tszyUrl}")
    private String tszyUrl;

    @Value("${api}")
    private String api;

    /**
     * 木渎二期token
     */
    private String token;

    private void getToken() {
        token = "Bearer " + loginService.getToken();
    }

    /**
     * 保存班前班后数据
     */
//    @GetMapping("/bqbh")
//    @ApiOperation(value = "保存班前班后数据")
    @Scheduled(cron = "0 0 1 * * ? ")
//    @Scheduled(cron = "0 0/5 * * * ?")
    public void saveBqbh() {
        getToken();
        String res = HttpRequest.get(bqbhUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<ASafeBqbhpx> aSafeBqbhpxes = new ArrayList<>();
        List<ASafeBqbhpxRequest> list = JSON.parseArray(dataList, ASafeBqbhpxRequest.class);
        for (ASafeBqbhpxRequest x : list) {
            ASafeBqbhpx aSafeBqbhpx = BeanUtil.copyProperties(x, ASafeBqbhpx.class);
            XcTpResponse xcTpResponse = new XcTpResponse();
            if (StrUtil.isNotEmpty(aSafeBqbhpx.getPxxctp())) {
                xcTpResponse.setFJDZ(api + aSafeBqbhpx.getPxxctp());
                xcTpResponse.setFJHZ(aSafeBqbhpx.getPxxctp().substring(aSafeBqbhpx.getPxxctp().lastIndexOf(".") + 1));
                xcTpResponse.setFJLX("");
                xcTpResponse.setFJMC(aSafeBqbhpx.getPxxctp().substring(aSafeBqbhpx.getPxxctp().lastIndexOf("/") + 1));
                //实体类转为JSONObject
                JSONArray jsonArray = new JSONArray(xcTpResponse);
                aSafeBqbhpx.setPxxctp(String.valueOf(jsonArray));
            }
//            EnterpriseResponse a = enterpriseService.findByQybh(aSafeBqbhpx.getQybh());
//            if (a!=null){
//                ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(a.getName(), a.getCertificateCode());
//                if (aSafeQyjcxx==null){
//                    continue;
//                }
//                aSafeBqbhpx.setQybh(aSafeQyjcxx.getXxbh());
//                aSafeBqbhpxes.add(aSafeBqbhpx);
//            }

            ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(null, x.getEntCode());
            aSafeBqbhpx.setQybh(aSafeQyjcxx.getXxbh());
            aSafeBqbhpxes.add(aSafeBqbhpx);
        }
        if (CollectionUtil.isNotEmpty(aSafeBqbhpxes)) {
            safeBqbhpxService.saveBatch(aSafeBqbhpxes);
        }
    }

    /**
     * 保存特殊作业数据
     */
//    @GetMapping("/tszy")
//    @ApiOperation(value = "保存特殊作业数据")
    @Scheduled(cron = "0 0 1 * * ? ")
//    @Scheduled(cron = "0 0/5 * * * ?")
    public void saveTszy() {
        getToken();
        String res = HttpRequest.get(tszyUrl)
                .contentType("application/x-www-form-urlencoded;charset=UTF-8")
                .header("Authorization", token)
                .execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        if (StrUtil.isEmpty(dataList)) {
            return;
        }
        List<ASafeQyzypgl> aSafeQyzypgls = new ArrayList<>();
        List<ASafeQyzypglRequest> list = JSON.parseArray(dataList, ASafeQyzypglRequest.class);
        for (ASafeQyzypglRequest x : list) {
          //  EnterpriseResponse a = enterpriseService.findByQybh(x.getQybh());
//            if (a!=null){
//                ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(a.getName(), a.getCertificateCode());
//                if (aSafeQyjcxx==null){
//                    continue;
//                }
//
//            }
            ASafeQyjcxx aSafeQyjcxx = aSafeQyjcxxService.findOneByqymcOrXybm(x.getQymc(), x.getEntCode());
            ASafeQyzypgl aSafeQyzypgl = BeanUtil.copyProperties(x, ASafeQyzypgl.class);
                aSafeQyzypgl.setQybh(aSafeQyjcxx.getXxbh());
                aSafeQyzypgls.add(aSafeQyzypgl);
        }
        if (CollectionUtil.isNotEmpty(aSafeQyzypgls)) {
            safeQyzypglService.saveBatch(aSafeQyzypgls);
        }
    }
}
