package com.mudu.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mudu.entity.ASafeQyjcxx;
import com.mudu.entity.dto.response.EnterpriseResponse;
import com.mudu.entity.dto.response.GeneralResponse;
import com.mudu.mapper.ASafeQyjcxxMapper;
import com.mudu.service.ASafeQyjcxxService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * (ASafeQyjcxx)表服务实现类
 *
 * @author wu
 * @since 2024-02-26 10:43:24
 */
@Service("aSafeQyjcxxService")
public class ASafeQyjcxxServiceImpl extends ServiceImpl<ASafeQyjcxxMapper, ASafeQyjcxx> implements ASafeQyjcxxService {

    @Value("${url}")
    private String url;

    /**
     * 将字符串中的中文括号替换为英文括号
     *
     * @param str 字符串
     * @return 替换后的字符串
     */
    public static String replaceChineseBrackets(String str) {
        if (StrUtil.isNotEmpty(str)) {
            // 左括号 （Unicode 编码：\uFF08）
            str = str.replace("\uFF08", "(");
            // 右括号 （Unicode 编码：\uFF09）
            str = str.replace("\uFF09", ")");
        }
        return str;
    }

    /**
     * 数据同步
     */
    @Override
    public void dataSynchronous() {
        // 获取木渎企业数据
        String body = HttpRequest.get(url + "/mudu/enterprise/findAll").execute().body();
        GeneralResponse res = JSONUtil.toBean(body, GeneralResponse.class);
        if (BeanUtil.isNotEmpty(res.getData())) {
            String jsonStr = JSONUtil.toJsonStr(res.getData());
            List<EnterpriseResponse> list = JSONUtil.toList(jsonStr, EnterpriseResponse.class);
            // 相同的企业
            List<ASafeQyjcxx> arr = new ArrayList<>();
            // 只有木渎存在的企业
            List<EnterpriseResponse> entList = new ArrayList<>();
            // 遍历企业数据对比
            list.forEach(x -> {
                ASafeQyjcxx safeQyjcxx = findOneByqymcOrXybm(replaceChineseBrackets(x.getName()), x.getCertificateCode());
                if (BeanUtil.isNotEmpty(safeQyjcxx)) {
                    arr.add(safeQyjcxx);
                } else {
                    entList.add(x);
                }
            });
            System.out.println("重复的数据" + arr.size());
            System.out.println("不重复的数据" + entList.size());
        }
        // 填补我们ent表所有有点位的企业
    }

    /**
     * 根据企业名称或信用代码查询数据
     *
     * @param qymc 企业名称
     * @param xybm 信用代码
     * @return 数据
     */
    @Override
    public ASafeQyjcxx findOneByqymcOrXybm(String qymc, String xybm) {
        return baseMapper.findOneByqymcOrXybm(qymc, xybm);
    }
}

